using System;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class Gauge : Control
    {
        private GaugeDrawTemplate myGaugeDrawTemplate;
        private int myEQType, myTextOffsetX, myTextOffsetY, myGaugeOffsetX, myGaugeOffsetY;
        private RGB myFillTint, myLinesFillTint;
        private bool myDrawLinesFill;

        [XmlElement("GaugeDrawTemplate", IsNullable = false)]
        [Browsable(true), Description("Template that defines the art for this gauge")]
        public GaugeDrawTemplate GaugeDrawTemplate { get { return myGaugeDrawTemplate; } set { myGaugeDrawTemplate = value; } }

        [XmlElement("EQType", IsNullable = false)]
        [Browsable(true), Description("Defines what EQ value the gauge displays (HP, Mana, etc.)")]
        public int EQType { get { return myEQType; } set { myEQType = value; } }

        [XmlElement("FillTint", IsNullable = false)]
        [Browsable(true), Description("Color of the bar that fills in.")]
        public RGB FillTint { get { return myFillTint; } set { myFillTint = value; } }

        [XmlElement("DrawLinesFill", IsNullable = false)]
        [Browsable(true), Description("Whether or not to draw the lines filling in")]
        public bool DrawLinesFill { get { return myDrawLinesFill; } set { myDrawLinesFill = value; } }

        [XmlElement("LinesFillTint", IsNullable = false)]
        [Browsable(true), Description("Color of the lines when filling in")]
        public RGB LinesFillTint { get { return myLinesFillTint; } set { myLinesFillTint = value; } }

        [XmlElement("TextOffsetX", IsNullable = false)]
        [Browsable(true), Description("X-offset for the text associated with this gauge")]
        public int TextOffsetX { get { return myTextOffsetX; } set { myTextOffsetX = value; } }

        [XmlElement("TextOffsetY", IsNullable = false)]
        [Browsable(true), Description("Y-offset for the text associated with this gauge")]
        public int TextOffsetY { get { return myTextOffsetY; } set { myTextOffsetY = value; } }

        [XmlElement("GaugeOffsetX", IsNullable = false)]
        [Browsable(true), Description("X-offset for the gauge itself")]
        public int GaugeOffsetX { get { return myGaugeOffsetX; } set { myGaugeOffsetX = value; } }

        [XmlElement("GaugeOffsetY", IsNullable = false)]
        [Browsable(true), Description("Y-offset for the gauge itself")]
        public int GaugeOffsetY { get { return myGaugeOffsetY; } set { myGaugeOffsetY = value; } }

        public Gauge() : this(null) { }
        public Gauge(EQInterface eqInterface) : base(eqInterface) { }

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            Gauge temp_Gauge = obj as Gauge;
            if (temp_Gauge != null)
            {
                GaugeDrawTemplate = temp_Gauge.GaugeDrawTemplate;
                EQType = temp_Gauge.EQType;
                FillTint = temp_Gauge.FillTint;
                DrawLinesFill = temp_Gauge.DrawLinesFill;
                LinesFillTint = temp_Gauge.LinesFillTint;
                TextOffsetX = temp_Gauge.TextOffsetX;
                TextOffsetY = temp_Gauge.TextOffsetY;
                GaugeOffsetX = temp_Gauge.GaugeOffsetX;
                GaugeOffsetY = temp_Gauge.GaugeOffsetY;
            }
        }
    }
}
